# ALACORDER beta 7.3.2

[Learn how to use alacorder using the interactive guide](https://mybinder.org/v2/gh/sbrobson959/alacorder/6f1624f1c296bb77c61c6fd0c5a9243cbfb30541?urlpath=lab%2Ftree%2Findex.ipynb)

https://github.com/sbrobson959/alacorder
https://pypi.org/project/alacorder/

To install on Windows, open Command Prompt and enter "pip install alacorder". To start the interface, enter "python -m alacorder". On Mac, open the Terminal and enter "pip3 install alacorder" then "python3 -m alacorder". If pip, pip3, python, or python3 do not work from your computer, install anaconda, create a virtual environment, open a terminal, and then repeat these instructions.

If your copy of alacorder is corrupted, use "pip uninstall alacorder" or "pip3 uninstall alacorder" and then reinstall it. There may be a newer version.
